@@ -8,10 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts;
-BEGIN {
-  $Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts::AUTHORITY = 'cpan:RSRCHBOY';
-}
-$Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts::VERSION = '0.011';
+our $AUTHORITY = 'cpan:RSRCHBOY';
+$Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts::VERSION = '0.012';
 use strict;
 use warnings;
 
@@ -99,9 +97,9 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl Christian Walde <walde.christian@googlemail.com> Karen Etheridge
-<ether@cpan.org> Mike Doherty <doherty@cs.dal.ca> Olivier Mengué
-<dolmen@cpan.org>
+=for :stopwords Chris Weyl Christian Doherty Etheridge Karen Mengué Mike Olivier Walde
+
+=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
 =head1 NAME
 
@@ -109,7 +107,7 @@ Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts - Check your repo for merge-c
 
 =head1 VERSION
 
-This document describes version 0.011 of Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts - released April 11, 2014 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
+This document describes version 0.012 of Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts - released February 23, 2015 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
 
 =head1 SYNOPSIS
 
@@ -145,8 +143,8 @@ L<Dist::Zilla::Plugin::Git::CheckFor>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor>
-and may be cloned from L<git://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor.git>
+The development version is on github at L<http://https://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor>
+and may be cloned from L<git://https://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor.git>
 
 =head1 BUGS
 
@@ -161,6 +159,25 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head2 I'm a material boy in a material world
+
+=begin html
+
+<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
+<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-git-checkfor&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-Git-CheckFor&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-Git-CheckFor%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
+
+=end html
+
+Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
+rather B<it is simply a very pleasant surprise>. I largely create and release
+works like this because I need them or I find it enjoyable; however, don't let
+that stop you if you feel like it ;)
+
+L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-git-checkfor&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-Git-CheckFor&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-Git-CheckFor%20in%20the%20CPAN%22>,
+L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by Chris Weyl.
