@@ -8,11 +8,9 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Dist::Zilla::PluginBundle::Git::CheckFor;
-BEGIN {
-  $Dist::Zilla::PluginBundle::Git::CheckFor::AUTHORITY = 'cpan:RSRCHBOY';
-}
-# git description: 0.010-5-g3a87784
-$Dist::Zilla::PluginBundle::Git::CheckFor::VERSION = '0.011';
+our $AUTHORITY = 'cpan:RSRCHBOY';
+# git description: 0.011-2-ga3f62a9
+$Dist::Zilla::PluginBundle::Git::CheckFor::VERSION = '0.012';
 
 # ABSTRACT: All Git::CheckFor plugins at once
 
@@ -45,9 +43,9 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl Christian Walde Karen Etheridge Mike Doherty Olivier Mengué
-<walde.christian@googlemail.com> <ether@cpan.org> <doherty@cs.dal.ca>
-<dolmen@cpan.org>
+=for :stopwords Chris Weyl Christian Doherty Etheridge Karen Mengué Mike Olivier Walde
+
+=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
 =head1 NAME
 
@@ -55,7 +53,7 @@ Dist::Zilla::PluginBundle::Git::CheckFor - All Git::CheckFor plugins at once
 
 =head1 VERSION
 
-This document describes version 0.011 of Dist::Zilla::PluginBundle::Git::CheckFor - released April 11, 2014 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
+This document describes version 0.012 of Dist::Zilla::PluginBundle::Git::CheckFor - released February 23, 2015 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
 
 =head1 SYNOPSIS
 
@@ -98,8 +96,8 @@ L<Dist::Zilla::PluginBundle::Git>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor>
-and may be cloned from L<git://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor.git>
+The development version is on github at L<http://https://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor>
+and may be cloned from L<git://https://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor.git>
 
 =head1 BUGS
 
@@ -114,8 +112,29 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head2 I'm a material boy in a material world
+
+=begin html
+
+<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
+<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-git-checkfor&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-Git-CheckFor&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-Git-CheckFor%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
+
+=end html
+
+Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
+rather B<it is simply a very pleasant surprise>. I largely create and release
+works like this because I need them or I find it enjoyable; however, don't let
+that stop you if you feel like it ;)
+
+L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-git-checkfor&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-Git-CheckFor&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-Git-CheckFor%20in%20the%20CPAN%22>,
+L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+
 =head1 CONTRIBUTORS
 
+=for stopwords Christian Walde Karen Etheridge Mike Doherty Olivier Mengué
+
 =over 4
 
 =item *
